@echo off
setlocal EnableExtensions
rem Hotfix patch tool v1.4 - SPR 1178466

Rem Allow bat file starting from UNC path
pushd %~dp0
cls

rem goto verify

Rem Check if correct client version is installed
reg query "HKCU\Software\SolidWorks\Applications\PDMWorks Enterprise" /v "FileExtVer" |find "28.2" >nul
if %errorlevel% EQU 1 (goto WrongVersion)
goto CheckFiles

:WrongVersion
Echo ----------------------
Echo Failed to determine installed version
Echo ----------------------
Rem Ignore if started in Quiet mode
if(%1)==(Q) (Goto CheckFiles)
if(%1)==(q) (Goto CheckFiles)
Echo Patch should only be installed on an SOLIDWORKS PDM 2020 SP2 system.
Echo Only continue if you are certain that this version is installed.
Echo ----------------------
SET /P ANSWER=Do you want to continue (y/n)?
if /i {%ANSWER%}=={y} (goto CheckFiles)
if /i {%ANSWER%}=={yes} (goto CheckFiles)
if /i {%ANSWER%}=={Y} (goto CheckFiles)
if /i {%ANSWER%}=={YES} (goto CheckFiles)
goto QuietCheck

:CheckFiles
Rem Check that patch source files are found
if NOT exist ".\x64\ConisioCAD.dll" (goto FileMissing)
goto FileOk

:FileMissing
Echo ------------------------------
Echo Script cannot find patch files. 
Echo Please verify all files and folders included with patch are present.
Echo ------------------------------
Rem check if started in Quiet mode
if(%1)==(Q) (Goto End)
if(%1)==(q) (Goto End)
Pause
exit

:FileOk


Echo SOLIDWORKS PDM Hotfix patch tool
if(%1)==(Q) (Goto GoOn)
if(%1)==(q) (Goto GoOn)
Rem Show warning
Echo --------------------------------
Echo This script will replace SOLIDWORKS PDM program files on the system.
Echo --------------------------------
SET /P ANSWER=Do you want to continue (y/n)?
if /i {%ANSWER%}=={y} (goto GoOn)
if /i {%ANSWER%}=={yes} (goto GoOn)
if /i {%ANSWER%}=={Y} (goto GoOn)
if /i {%ANSWER%}=={YES} (goto GoOn)
exit

:GoOn

Rem Kill processes holding on to SOLIDWORKS PDM files
Echo ---------------------------------------------------------
Echo Kill processes holding on to files to be replaced...
Rem first DLL
tasklist /m ConisioCAD.dll /nh |findstr ConisioCAD.dll >nul
IF %errorlevel% EQU 0 (
FOR /F "tokens=2" %%A IN ('tasklist /m ConisioCAD.dll /fo TABLE /nh') DO (taskkill /PID:%%A /F)
)

Rem Get SW PDM install location
FOR /F "tokens=2* delims=	 " %%A IN ('reg query "HKLM\Software\SolidWorks\Applications\PDMWorks Enterprise" /v "Location"') DO SET InstallFolder=%%B

Rem Get SW PDM x32 install location
FOR /F "tokens=2* delims=	 " %%A IN ('reg query "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\SolidWorks\Applications\PDMWorks Enterprise" /v "Location"') DO SET InstallFolderx86=%%B

Echo --------------------
Echo Backup DLLs...
Echo to "%Temp%\SWPDMDllBackup"
if NOT exist "%Temp%\SWPDMDllBackup\x64" mkdir "%Temp%\SWPDMDllBackup\x64"

Echo from "%InstallFolder%ConisioCAD.dll"
COPY /Y "%InstallFolder%ConisioCAD.dll" "%Temp%\SWPDMDllBackup\x64\ConisioCAD.dll"


Echo ---------------------
Echo Replace DLLs...


Echo Replace "%InstallFolder%ConisioCAD.dll"
COPY /Y ".\x64\ConisioCAD.dll" "%InstallFolder%ConisioCAD.dll"



:verify

Rem Verify replaced files

Echo --------------------------
Echo Verifying replaced files...
set CompareErrorFlag=0


fc /b ".\x64\ConisioCAD.dll" "%InstallFolder%ConisioCAD.dll" > nul 
if errorlevel 1 (set CompareErrorFlag=1
echo "%InstallFolder%ConisioCAD.dll" - Mismatched
) else (echo "%InstallFolder%ConisioCAD.dll" - OK)


if %CompareErrorFlag%==0 goto Done

:CompareError
Echo ----------------------
Echo Patch failed - One or more replaced files are mismatched.
echo Close all applications and try running patch again.
Echo ----------------------
goto RestartProcess

:Done

Echo --------------------------
Echo Updating registry value to enable asynchronous loading in add-in
regedit /s EnableAddinAsyncRefresh.reg

Echo ----------------------
Echo Done - Hotfix applied
Echo ----------------------

:RestartProcess
Rem restart explorer.exe if not running
tasklist /v |findstr explorer.exe >nul
IF %errorlevel% EQU 1 (
Echo --------------------------
Echo Starting Explorer... 
start explorer.exe)

:QuietCheck
Rem check if started in Quiet mode
if(%1)==(Q) (Goto End)
if(%1)==(q) (Goto End)
Pause

:END